@@ -12,7 +12,7 @@ from typing_extensions import Literal
 if sys.version_info >= (3, 8):
     from typing import get_args
 else:
-    from typing_extensions import get_args
+    from typing_extensions import get_args  # pragma: no cover
 
 
 QUERY_PARAMS = ["criteria", "properties", "skip", "limit"]
